@@ -1,5 +1,8 @@
+import asyncio
 import os
+import tempfile
 from argparse import Namespace
+from functools import partial
 from pathlib import Path
 from typing import Dict, Optional, Tuple
 
@@ -12,7 +15,8 @@ from simple_term_menu import TerminalMenu
 
 from dstack.cli.common import ask_choice, console
 from dstack.core.config import BackendConfig, Configurator, get_config_path
-from dstack.core.error import ConfigError
+from dstack.core.error import ConfigError, HubError
+from dstack.hub.models import GCPProjectValues, ProjectElement, ProjectElementValue
 
 DEFAULT_GEOGRAPHIC_AREA = "North America"
 
@@ -189,14 +193,14 @@ class GCPConfigurator(Configurator):
         return GCPConfig.deserialize(data=data)
 
     def register_parser(self, parser):
-        aws_parser = parser.add_parser("gcp", help="", formatter_class=RichHelpFormatter)
-        aws_parser.add_argument("--bucket", type=str, help="", required=True)
-        aws_parser.add_argument("--project", type=str, help="", required=True)
-        aws_parser.add_argument("--region", type=str, help="", required=True)
-        aws_parser.add_argument("--zone", type=str, help="", required=True)
-        aws_parser.add_argument("--vpc", type=str, help="", required=True)
-        aws_parser.add_argument("--subnet", type=str, help="", required=True)
-        aws_parser.set_defaults(func=self._command)
+        gcp_parser = parser.add_parser("gcp", help="", formatter_class=RichHelpFormatter)
+        gcp_parser.add_argument("--bucket", type=str, help="", required=True)
+        gcp_parser.add_argument("--project", type=str, help="", required=True)
+        gcp_parser.add_argument("--region", type=str, help="", required=True)
+        gcp_parser.add_argument("--zone", type=str, help="", required=True)
+        gcp_parser.add_argument("--vpc", type=str, help="", required=True)
+        gcp_parser.add_argument("--subnet", type=str, help="", required=True)
+        gcp_parser.set_defaults(func=self._command)
 
     def _command(self, args: Namespace):
         config = GCPConfig(
@@ -210,8 +214,148 @@ class GCPConfigurator(Configurator):
         config.save()
         print(f"[grey58]OK[/]")
 
+    def _get_hub_buckets(self, credentials, default: Optional[str] = None):
+        element = ProjectElement(selected=default)
+        storage_client = storage.Client(credentials=credentials)
+        buckets = storage_client.list_buckets()
+        for bucket in buckets:
+            element.values.append(ProjectElementValue(value=bucket.name, label=bucket.name))
+        return element
+
+    def _get_hub_geographic_area(self, default_area: Optional[str]):
+        if default_area is None:
+            default_area = DEFAULT_GEOGRAPHIC_AREA
+        area_names = sorted([l["name"] for l in GCP_LOCATIONS])
+        element = ProjectElement(selected=default_area)
+        for area_name in area_names:
+            element.values.append(ProjectElementValue(value=area_name, label=area_name))
+        return element
+
+    def _get_hub_region(
+        self, credentials, project_id, location: Dict, default_region: Optional[str]
+    ):
+        regions_client = compute_v1.RegionsClient(credentials=credentials)
+        list_regions_request = compute_v1.ListRegionsRequest(project=project_id)
+        regions = regions_client.list(list_regions_request)
+        region_names = sorted(
+            [r.name for r in regions if r.name in location["regions"]],
+            key=lambda name: (name != location["default_region"], name),
+        )
+        element = ProjectElement(selected=default_region)
+        for region_name in region_names:
+            element.values.append(ProjectElementValue(value=region_name, label=region_name))
+
+        return element, {r.name: r for r in regions}
+
+    def _get_hub_zone(
+        self, location: Dict, region: compute_v1.Region, default_zone: Optional[str]
+    ):
+        zone_names = sorted(
+            [self._get_resource_name(z) for z in region.zones],
+            key=lambda name: (name != location["default_zone"], name),
+        )
+        if default_zone not in zone_names:
+            default_zone = zone_names[0]
+        element = ProjectElement(selected=default_zone)
+        for zone_name in zone_names:
+            element.values.append(ProjectElementValue(value=zone_name, label=zone_name))
+
+        return element
+
+    def _get_hub_vpc_subnet(
+        self,
+        credentials,
+        project_id,
+        region,
+        default_vpc: Optional[str],
+        default_subnet: Optional[str],
+    ):
+        networks_client = compute_v1.NetworksClient(credentials=credentials)
+        list_networks_request = compute_v1.ListNetworksRequest(project=project_id)
+        networks = networks_client.list(list_networks_request)
+        element = ProjectElement(selected=f"{default_vpc},{default_subnet}")
+        for network in networks:
+            for subnet in network.subnetworks:
+                subnet_region = self._get_subnet_region(subnet)
+                if subnet_region != region:
+                    continue
+                element.values.append(
+                    ProjectElementValue(
+                        vpc=network.name,
+                        subnet=self._get_subnet_name(subnet),
+                        label=f"({network.name},{self._get_subnet_name(subnet)})",
+                    )
+                )
+        return element
+
     async def configure_hub(self, data: Dict):
-        pass
+        loop = asyncio.get_event_loop()
+        if data.get("credentials") is not None:
+            fd, tmp_path = tempfile.mkstemp()
+            try:
+                with os.fdopen(fd, "w") as tmp:
+                    tmp.write(data.get("credentials"))
+                try:
+                    credentials = service_account.Credentials.from_service_account_file(tmp_path)
+                    storage_client = storage.Client(credentials=credentials)
+                    storage_client.list_buckets(max_results=1)
+                except Exception as e:
+                    raise HubError("Credentials are not valid")
+                project_values = GCPProjectValues()
+                project_values.bucket_name = await loop.run_in_executor(
+                    None,
+                    partial(
+                        self._get_hub_buckets,
+                        credentials=credentials,
+                        default=data.get("bucket_name"),
+                    ),
+                )
+                default_area = self._get_region_geographic_area(data.get("region"))
+                project_values.area = await loop.run_in_executor(
+                    None, partial(self._get_hub_geographic_area, default_area=default_area)
+                )
+                if data.get("area") is not None:
+                    location = self._get_location(data.get("area"))
+                    project_values.region, regions = await loop.run_in_executor(
+                        None,
+                        partial(
+                            self._get_hub_region,
+                            credentials=credentials,
+                            project_id=credentials.project_id,
+                            location=location,
+                            default_region=default_area,
+                        ),
+                    )
+                    if (
+                        data.get("region") is not None
+                        and regions.get(data.get("region")) is not None
+                    ):
+                        project_values.zone = await loop.run_in_executor(
+                            None,
+                            partial(
+                                self._get_hub_zone,
+                                location=location,
+                                region=regions.get(data.get("region")),
+                                default_zone=data.get("zone"),
+                            ),
+                        )
+
+                        project_values.vpc_subnet = await loop.run_in_executor(
+                            None,
+                            partial(
+                                self._get_hub_vpc_subnet,
+                                credentials=credentials,
+                                project_id=credentials.project_id,
+                                region=data.get("region"),
+                                default_vpc=data.get("vpc"),
+                                default_subnet=data.get("subnet"),
+                            ),
+                        )
+                return project_values
+            finally:
+                os.remove(path=tmp_path)
+        else:
+            raise HubError("Credentials are not valid")
 
     def configure_cli(self):
         credentials_file = None
