@@ -1,7 +1,9 @@
-class Secret:
-    def __init__(self, secret_name: str, secret_value: str):
-        self.secret_name = secret_name
-        self.secret_value = secret_value
+from pydantic import BaseModel
+
+
+class Secret(BaseModel):
+    secret_name: str
+    secret_value: str
 
     def __str__(self) -> str:
         return (
